@@ -1,16 +1,16 @@
 # Tests for valid outputs ----
 
 # Output should be a data frame with 15 columns
-# test_that("data frame output format", {
-#   expect_message(ex <- GIFT_lists(GIFT_version = "beta"),
-#                  "You are asking for the beta-version of GIFT which is subject to
-# updates and edits. Consider using 'latest' for the latest stable
-# version.")
-#   
-#   expect_s3_class(ex, "data.frame")
-#   expect_identical(ncol(ex), c(15L))
-#   
-# })
+test_that("data frame output format", {
+  expect_message(ex <- GIFT_lists(GIFT_version = "beta"),
+                 "You are asking for the beta-version of GIFT which is subject to
+updates and edits. Consider using 'latest' for the latest stable
+version.")
+
+  expect_s3_class(ex, "data.frame")
+  expect_identical(ncol(ex), c(15L))
+
+})
 
 # Tests for invalid inputs ----
 test_that("invalid inputs", {
